@@ -3,4 +3,4 @@ import importlib.metadata
 __version__ = importlib.metadata.version("mem0ai")
 
 from mem0.client.main import AsyncMemoryClient, MemoryClient  # noqa
-from mem0.memory.main import Memory, AsyncMemory  # noqa
+from mem0.memory.main import AsyncMemory, Memory  # noqa
