@@ -23,6 +23,8 @@ class EmbedderConfig(BaseModel):
             "together",
             "lmstudio",
             "langchain",
+            "aws_bedrock",
+            "fastembed",
         ]:
             return v
         else:
